@@ -3,7 +3,7 @@ package POE::Component::OpenSSH;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moose;
 use Net::OpenSSH;
@@ -46,7 +46,7 @@ POE::Component::OpenSSH - Nonblocking SSH Component for POE using Net::OpenSSH
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -55,16 +55,25 @@ Need nonblocking SSH? You like Net::OpenSSH? Try out this stuff right here.
     use POE::Component::OpenSSH;
 
     my $ssh = POE::Component::OpenSSH->new( args => [ $host, user => $user ] );
+    $ssh->obj->system( { event => 'read_system_output' }, 'w' );
+
+Perhaps you want it with debugging and verbose of POE::Component::Generic
 
-    # perhaps using verbose, debug?
     my $ssh = POE::Component::OpenSSH->new(
-        args    => [ ''root@host', passwd => $pass ],
+        args    => [ 'root@host', passwd => $pass ],
         verbose => 1, # turns on POE::Component::Generic verbose
         debug   => 1, # turns on POE::Component::Generic debug
     );
-    ...
 
-Here is an example using L<MooseX::POE>. If you know POE::Session, you can use that too:
+What about setting timeout for Net::OpenSSH?
+
+    my $ssh = POE::Component::OpenSSH->new(
+        args => [ 'root@host', passwd => $pass, timeout => 10 ],
+    );
+
+Here is an example using L<MooseX::POE>:
+
+(If you know <POE::Session>, you can use that too)
 
     package Runner;
 
@@ -98,6 +107,8 @@ Here is an example using L<MooseX::POE>. If you know POE::Session, you can use t
 
     package main;
 
+    use POE::Kernel;
+
     my @machines = ( qw( server1 server2 server3 ) );
 
     foreach my $machine (@machines) {
@@ -108,6 +119,8 @@ Here is an example using L<MooseX::POE>. If you know POE::Session, you can use t
         );
     }
 
+    POE::Kernel->run();
+
 =head1 DESCRIPTION
 
 This module allows you to use SSH (via L<Net::OpenSSH>) in a nonblocking manner.
@@ -118,6 +131,43 @@ You might ask 'why put the args in an "args" attribute instead of straight away
 
 It's on Github so you can patch it up if you want (I accept patches... and foodstamps).
 
+=head1 METHODS
+
+=head2 new
+
+Creates a new POE::Component::OpenSSH object. If you want to access the Net::OpenSSH check I<obj> below.
+
+You should note this object is simply a component, you're still required to put it in a L<POE::Session>. The examples use L<MooseX::POE> which does the same thing.
+
+=head2 obj
+
+This method access the actual Net::OpenSSH object. It is wrapped with L<POE::Component::Generic>, so the first argument is actually a hashref that POE::Component::Generic requires. Specifically, noting which event will handle the return of the Net::OpenSSH method.
+
+For example:
+
+    $ssh->obj->capture( { event => 'handle_capture' }, 'echo yo yo' );
+
+=head2 args
+
+These are the arguments that will go to L<Net::OpenSSH> creation. This is an arrayref.
+
+For example:
+
+    # using user@host
+    my $ssh = POE::Component::OpenSSH->new( args => [ 'root@remote_host' ] );
+
+    # using separate arguments
+    my $ssh = POE::Component::OpenSSH->new( args => [ 'remote_host, user => 'root' ] );
+
+    # same thing, just with pass, and writing it nicer
+    my $ssh = POE::Component::OpenSSH->new(
+        args => [
+            'remote_host',
+            user   => 'root',
+            passwd => $pass,
+        ],
+    );
+
 =head1 AUTHOR
 
 Sawyer X, C<< <xsawyerx at cpan.org> >>
@@ -178,8 +228,6 @@ If you don't know POE at all, check L<POE>.
 
 =head1 DEPENDENCIES
 
-These are the actual dependencies, though I don't use Moose or POE directly but rather MooseX::POE.
-
 L<Net::OpenSSH>
 
 L<POE>
@@ -188,9 +236,6 @@ L<POE::Component::Generic>
 
 L<Moose>
 
-L<MooseX::POE>
-
-
 =head1 ACKNOWLEDGEMENTS
 
 All the people involved in the aforementioned projects and the Perl community.
